package com.yaozhitech.spring5.controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.yaozhitech.spring5.annotation.IgnoreClientToken;
import com.yaozhitech.spring5.provider.AdminProvider;
import com.yaozhitech.spring5.utils.JwtUtils;

import lombok.extern.slf4j.Slf4j;

@Slf4j
@RestController
@RequestMapping("/order")
public class OrderController {
	
	@Autowired
	private AdminProvider adminProvider;
	
	@Value("${spring.application.name}")
    private String applicationName;
	
	@Value("${auth.client.secret}")
    private String clientSecret;
	
	@Value("$jwt.salt}")
	private String jwtSalt;

	@GetMapping("/{id}")
	public ResponseEntity<String> read(@PathVariable Long id) {
		return ResponseEntity.ok(adminProvider.admin(id));
	}
	
	@IgnoreClientToken
	@GetMapping("/token")
	public ResponseEntity<String> token() {
		String token = JwtUtils.sign(applicationName + "." + clientSecret, jwtSalt, 3600);
		
		String decodeToken = JwtUtils.getUsername(token);
		log.info(decodeToken);
		
		decodeToken = JwtUtils.verifyTokenAndGet("eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJleHAiOjE1NzY3NTgzMjUsImlhdCI6MTU3Njc1NDcyNSwidXNlcm5hbWUiOiJvcmRlci5xeDRNWFZSOVNKbTMxcTJDIn0.W_1wgNjhIfB-3D_v7qhqlpxzc2setbAtHo0Iich_GFc",
				jwtSalt);
		log.info(decodeToken);
		
		return ResponseEntity.ok(token);
	}
}
